@@ -30,7 +30,7 @@ use strict;
 use warnings;
 use 5.006;
 use Carp;
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK $AUTOLOAD);
+use vars qw(@ISA @EXPORT @EXPORT_OK $AUTOLOAD);
 
 use overload (
 	'""'  =>   sub { stringify($_[0]) },
@@ -65,7 +65,7 @@ require AutoLoader;
 # names by default without a very good reason. Use EXPORT_OK instead.
 # Do not simply export all your public functions/methods/constants.
 
-our $VERSION = '2.12';
+our $VERSION = '2.13';
 
 
 bootstrap Math::GMP $VERSION;
@@ -118,7 +118,7 @@ Math::GMP - High speed arbitrary size integer math
 
 =head1 VERSION
 
-version 2.12
+version 2.13
 
 =head1 SYNOPSIS
 
@@ -452,6 +452,26 @@ Returns the size of $x in base $plain_int_base .
 Returns the value of the object as an unblessed (and limited-in-precision)
 integer.
 
+=head2 _gmp_build_version()
+
+  my $gmp_version = Math::GMP::_gmp_build_version;
+  if ($gmp_version ge 6.0.0) {
+    print "Math::GMP was built against libgmp-6.0.0 or later";
+  }
+
+Class method that returns as a vstring the version of libgmp against which
+this module was built.
+
+=head2 _gmp_lib_version()
+
+  my $gmp_version = Math::GMP::_gmp_lib_version;
+  if ($gmp_version ge 6.0.0) {
+    print "Math::GMP is now running with libgmp-6.0.0 or later";
+  }
+
+Class method that returns as a vstring the version of libgmp it is currently
+running.
+
 =head2 gcd()
 
 An alias to bgcd() .
@@ -572,7 +592,7 @@ This is free software, licensed under:
 
 Please report any bugs or feature requests on the bugtracker website
 https://rt.cpan.org/Public/Dist/Display.html?Name=Math-GMP or by email to
-bug-math-fft@rt.cpan.org.
+bug-math-gmp@rt.cpan.org.
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
